@@ -1,7 +1,10 @@
+from multiprocessing import Pool
 import os
+import random
 import shutil
 import glob
 import unittest
+import time
 from fireworks.core.firework import FireWork, Workflow
 from fireworks.core.fworker import FWorker
 from fireworks.core.launchpad import LaunchPad
@@ -24,6 +27,7 @@ __date__ = 'Mar 06, 2013'
 
 TESTDB_NAME = 'fireworks_unittest'
 MODULE_DIR = os.path.dirname(os.path.abspath(__file__))
+NCORES_PARALLEL_TEST = 4
 
 #TODO: make these tests much better. Right now they are just a crude first line of defense.
 
@@ -32,6 +36,12 @@ MODULE_DIR = os.path.dirname(os.path.abspath(__file__))
 
 # TODO: cleanup!!
 
+def random_launch(lp_creds):
+        lp = LaunchPad.from_dict(lp_creds)
+        while lp.run_exists(None):
+            launch_rocket(lp)
+            time.sleep(random.random()/3+0.1)
+
 class MongoTests(unittest.TestCase):
 
     @classmethod
@@ -149,6 +159,20 @@ class MongoTests(unittest.TestCase):
         self.assertEqual(self.lp.get_launch_by_id(3).action.stored_data, {})
         self.assertFalse(self.lp.run_exists())
 
+    def test_parallel_fibadder(self):
+        # this is really testing to see if a Workflow can handle multiple FWs updating it at once
+        parent = FireWork(ScriptTask.from_str("python -c 'print(\"test1\")'", {'store_stdout': True}), fw_id=1)
+        fib1 = FireWork(FibonacciAdderTask(), {'smaller': 0, 'larger': 1, 'stop_point': 30}, fw_id=2)
+        fib2 = FireWork(FibonacciAdderTask(), {'smaller': 0, 'larger': 1, 'stop_point': 30}, fw_id=3)
+        wf = Workflow([parent, fib1, fib2], {1: [2, 3]})
+        self.lp.add_wf(wf)
+
+        p = Pool(NCORES_PARALLEL_TEST)
+
+        creds_array = [self.lp.to_dict()] * NCORES_PARALLEL_TEST
+        p.map(random_launch, creds_array)
+
+
     def test_fworkerenv(self):
         t = DummyTask()
         fw = FireWork(t)
